@@ -8,14 +8,14 @@
 #' \code{c("chl", "Peru")}). Default set to \code{NULL}.
 #' @param partners ISO code for partner country (e.g. \code{"chl"}, \code{Chile} or
 #' \code{c("chl", "Peru")}). Default set to \code{NULL}.
-#' @param products HS codes (e.g. \code{"0101"}, \code{"01"} or search matches for \code{"apple"}) 
+#' @param products HS codes (e.g. \code{"0101"}, \code{"01"} or search matches for \code{"apple"})
 #' to filter products. Default set to \code{"all"}.
 #' @param product_code_length Character string to indicate the granularity level on products
 #' Default set to \code{4} (it can also take the values \code{6} or
 #' \code{all}).
 #' @param table Character string to select the table to obtain the data.
 #' Default set to \code{yrpc} (Year - Reporter - Partner - Product Code).
-#' Run \code{ots_attributes_tables} in case of doubt.
+#' Run \code{ots_tables} in case of doubt.
 #' @param max_attempts How many times to try to download data in case the
 #' API or the internet connection fails when obtaining data. Default set
 #' to \code{5}.
@@ -23,6 +23,8 @@
 #' Default set to \code{FALSE}.
 #' @param include_communities Whether to include or not to include product communities.
 #' Default set to \code{FALSE}.
+#' @param use_localhost Logical to determine if the base URL shall be localhost instead
+#' of api.tradestatistics.io. Default set to \code{FALSE}.
 #' @return A tibble that describes bilateral trade metrics (imports,
 #' exports, trade balance and relevant metrics
 #' such as exports growth w/r to last year) between a \code{reporter}
@@ -39,17 +41,17 @@
 #' \dontrun{
 #' # The next example can take more than 5 seconds to compute,
 #' # so these are just shown without evaluation according to CRAN rules
-#' 
-#' # Run `ots_attributes_countries` to display the full table of countries
-#' # Run `ots_attributes_products` to display the full table of products
-#' 
+#'
+#' # Run `ots_countries` to display the full table of countries
+#' # Run `ots_products` to display the full table of products
+#'
 #' # What does Chile export to China? (1980)
 #' ots_create_tidy_data(years = 1980, reporters = "chl", partners = "chn")
-#' 
+#'
 #' # What can we say about Horses export in Chile and the World? (1980)
 #' ots_create_tidy_data(years = 1980, products = "0101", table = "yc")
 #' ots_create_tidy_data(years = 1980, reporters = "chl", products = "0101", table = "yrc")
-#' 
+#'
 #' # What can we say about the different types of apples exported by Chile? (1980)
 #' ots_create_tidy_data(years = 1980, reporters = "chl", products = "apple", table = "yrc")
 #' }
@@ -63,27 +65,30 @@ ots_create_tidy_data <- function(years = NULL,
                                  table = "yrpc",
                                  max_attempts = 5,
                                  include_shortnames = FALSE,
-                                 include_communities = FALSE) {
+                                 include_communities = FALSE,
+                                 use_localhost = FALSE) {
 
   # Check tables ------------------------------------------------------------
-  if (!table %in% tradestatistics::ots_attributes_tables$table) {
+  if (!table %in% tradestatistics::ots_tables$table) {
     stop(
       "
-      The requested table does not exist. Please check the spelling or 
-      explore the 'ots_attributes_table' table provided within this package.
+      The requested table does not exist. Please check the spelling or
+      explore the 'ots_table' table provided within this package.
       "
     )
   }
 
   # Check years -------------------------------------------------------------
   year_depending_queries <- grep("^reporters|rankings$|^y",
-                                 tradestatistics::ots_attributes_tables$table, value = T)
-  
+    tradestatistics::ots_tables$table,
+    value = T
+  )
+
   url <- "year_range"
-  
+
   resp <- crul::HttpClient$new(url = "https://api.tradestatistics.io/")
   resp <- resp$get(url)
-  
+
   year_range <- purrr::as_vector(jsonlite::fromJSON(resp$parse(encoding = "UTF-8")))
 
   if (all(years %in% min(year_range):max(year_range)) != TRUE &
@@ -91,111 +96,117 @@ ots_create_tidy_data <- function(years = NULL,
     stop(
       "
       Provided that the table you requested contains a 'year' field,
-      please verify that you are requesting data contained within 
+      please verify that you are requesting data contained within
       the years exposed in api.tradestatistics.io/year_range.
       "
     )
   }
 
   # Check reporters and partners --------------------------------------------
-  reporter_depending_queries <- grep("^yr", 
-                                     tradestatistics::ots_attributes_tables$table, value = T)
+  reporter_depending_queries <- grep("^yr",
+    tradestatistics::ots_tables$table,
+    value = T
+  )
   partner_depending_queries <- grep("^yrp",
-                                    tradestatistics::ots_attributes_tables$table, value = T)
+    tradestatistics::ots_tables$table,
+    value = T
+  )
 
   if (!is.null(reporters)) {
-    if (!all(reporters %in% tradestatistics::ots_attributes_countries$country_iso) == TRUE &
-        table %in% reporter_depending_queries) {
-        reporters_iso <- reporters[reporters %in% tradestatistics::ots_attributes_countries$country_iso]
-        reporters_no_iso <- reporters[!reporters %in% tradestatistics::ots_attributes_countries$country_iso]
-        
-        reporters_no_iso <- purrr::map_chr(
-          seq_along(reporters_no_iso),
-          function(x) {
-            y <- tradestatistics::ots_country_code(reporters_no_iso[x]) %>%
-              dplyr::select(!!sym("country_iso"))
-            
-            if (nrow(y) == 0) {
-              stop("The specified reporter returned no valid ISO code")
-            } else {
-              y <- purrr::as_vector(y)
-            }
-            
-            return(y)
+    if (!all(reporters %in% tradestatistics::ots_countries$country_iso) == TRUE &
+      table %in% reporter_depending_queries) {
+      reporters_iso <- reporters[reporters %in% tradestatistics::ots_countries$country_iso]
+      reporters_no_iso <- reporters[!reporters %in% tradestatistics::ots_countries$country_iso]
+
+      reporters_no_iso <- purrr::map_chr(
+        seq_along(reporters_no_iso),
+        function(x) {
+          y <- tradestatistics::ots_country_code(reporters_no_iso[x]) %>%
+            dplyr::select(!!sym("country_iso"))
+
+          if (nrow(y) == 0) {
+            stop("The specified reporter returned no valid ISO code")
+          } else {
+            y <- purrr::as_vector(y)
           }
-        )
-        
-        reporters <- c(reporters_iso, reporters_no_iso)
-    }
-  }
-  
-  if (!is.null(partners)) {
-    if (!all(partners %in% tradestatistics::ots_attributes_countries$country_iso) == TRUE &
-        table %in% partner_depending_queries) {
-        partners_iso <- partners[partners %in% tradestatistics::ots_attributes_countries$country_iso]
-        partners_no_iso <- partners[!partners %in% tradestatistics::ots_attributes_countries$country_iso]
-        
-        partners_no_iso <- purrr::map_chr(
-          seq_along(partners_no_iso),
-          function(x) {
-            y <- tradestatistics::ots_country_code(partners_no_iso[x]) %>%
-              dplyr::select(!!sym("country_iso"))
-            
-            if (nrow(y) == 0) {
-              stop("The specified partner returned no valid ISO code")
-            } else {
-              y <- purrr::as_vector(y)
-            }
-            
-            return(y)
-          }
-        )
-        
-        partners <- c(partners_iso, partners_no_iso)
-    }
-  }
-  
-  # Check product codes -----------------------------------------------------
-  product_depending_queries <- grep("c$",
-                                    tradestatistics::ots_attributes_tables$table, value = T)
-  
-  if(!all(as.character(products) %in% 
-          tradestatistics::ots_attributes_products$product_code) == TRUE &
-     table %in% product_depending_queries) {
-      
-      # products without match (wm)
-      products_wm <- products[!products %in% 
-                                tradestatistics::ots_attributes_products$product_code]
-      
-      # product name match (pmm)
-      pnm <- purrr::map_df(
-        .x = seq_along(products_wm), 
-        ~tradestatistics::ots_product_code(productname = products_wm[.x])
+
+          return(y)
+        }
       )
-      
-      # group name match (gnm)
-      gnm <- purrr::map_df(
-        .x = seq_along(products_wm), 
-        ~tradestatistics::ots_product_code(productgroup = products_wm[.x])
-      )
-      
-      products_wm <- bind_rows(pnm, gnm) %>% 
-        distinct(!!sym("product_code")) %>% 
-        as_vector()
-      
-      products <- c(products[products %in% 
-                               tradestatistics::ots_attributes_products$product_code], products_wm)
+
+      reporters <- c(reporters_iso, reporters_no_iso)
+    }
   }
 
-  if(!all(as.character(products) %in% 
-          tradestatistics::ots_attributes_products$product_code == TRUE) &
-     table %in% product_depending_queries) {
-      stop(
-        "
-        The requested products do not exist. Please check the spelling or 
-        explore the 'ots_attributes_products' table provided within this package.
-        "
+  if (!is.null(partners)) {
+    if (!all(partners %in% tradestatistics::ots_countries$country_iso) == TRUE &
+      table %in% partner_depending_queries) {
+      partners_iso <- partners[partners %in% tradestatistics::ots_countries$country_iso]
+      partners_no_iso <- partners[!partners %in% tradestatistics::ots_countries$country_iso]
+
+      partners_no_iso <- purrr::map_chr(
+        seq_along(partners_no_iso),
+        function(x) {
+          y <- tradestatistics::ots_country_code(partners_no_iso[x]) %>%
+            dplyr::select(!!sym("country_iso"))
+
+          if (nrow(y) == 0) {
+            stop("The specified partner returned no valid ISO code")
+          } else {
+            y <- purrr::as_vector(y)
+          }
+
+          return(y)
+        }
       )
+
+      partners <- c(partners_iso, partners_no_iso)
+    }
+  }
+
+  # Check product codes -----------------------------------------------------
+  product_depending_queries <- grep("c$",
+    tradestatistics::ots_tables$table,
+    value = T
+  )
+
+  if (!all(as.character(products) %in%
+    tradestatistics::ots_products$product_code) == TRUE &
+    table %in% product_depending_queries) {
+
+    # products without match (wm)
+    products_wm <- products[!products %in%
+      tradestatistics::ots_products$product_code]
+
+    # product name match (pmm)
+    pnm <- purrr::map_df(
+      .x = seq_along(products_wm),
+      ~ tradestatistics::ots_product_code(productname = products_wm[.x])
+    )
+
+    # group name match (gnm)
+    gnm <- purrr::map_df(
+      .x = seq_along(products_wm),
+      ~ tradestatistics::ots_product_code(productgroup = products_wm[.x])
+    )
+
+    products_wm <- bind_rows(pnm, gnm) %>%
+      distinct(!!sym("product_code")) %>%
+      as_vector()
+
+    products <- c(products[products %in%
+      tradestatistics::ots_products$product_code], products_wm)
+  }
+
+  if (!all(as.character(products) %in%
+    tradestatistics::ots_products$product_code == TRUE) &
+    table %in% product_depending_queries) {
+    stop(
+      "
+        The requested products do not exist. Please check the spelling or
+        explore the 'ots_products' table provided within this package.
+        "
+    )
   }
 
   # Read from API -----------------------------------------------------------
@@ -208,15 +219,15 @@ ots_create_tidy_data <- function(years = NULL,
       "
     )
   }
-  
+
   if (is.null(reporters)) {
     reporters <- ""
   }
-  
+
   if (is.null(partners)) {
     partners <- ""
   }
-  
+
   yrpc_grid <- expand.grid(
     year = years,
     reporter = reporters,
@@ -224,24 +235,26 @@ ots_create_tidy_data <- function(years = NULL,
     product = products,
     stringsAsFactors = FALSE
   )
-  
+
   years <- purrr::as_vector(yrpc_grid$year)
   reporters <- purrr::as_vector(yrpc_grid$reporter)
   partners <- purrr::as_vector(yrpc_grid$partner)
   products <- purrr::as_vector(yrpc_grid$product)
-  
-  data <- purrr::map_df(.x = seq_along(years),
-                   ~ots_read_from_api(
-                     table = table,
-                     max_attempts = max_attempts,
-                     year = years[.x],
-                     reporter = reporters[.x],
-                     partner = partners[.x],
-                     product_code = products[.x],
-                     product_code_length = product_code_length
-                   )
-    ) %>% 
-    dplyr::filter(!is.na(product_code_length)) %>% 
+
+  data <- purrr::map_df(
+    .x = seq_along(years),
+    ~ ots_read_from_api(
+      table = table,
+      max_attempts = max_attempts,
+      year = years[.x],
+      reporter = reporters[.x],
+      partner = partners[.x],
+      product_code = products[.x],
+      product_code_length = product_code_length,
+      use_localhost = use_localhost
+    )
+  ) %>%
+    dplyr::filter(!is.na(product_code_length)) %>%
     dplyr::as_tibble()
 
   # no data in API message
@@ -258,7 +271,7 @@ ots_create_tidy_data <- function(years = NULL,
     if (table %in% tables_with_reporter[1:2]) {
       data %<>%
         dplyr::left_join(dplyr::select(
-          tradestatistics::ots_attributes_countries,
+          tradestatistics::ots_countries,
           !!!rlang::syms(
             c("country_iso", "country_fullname_english")
           )
@@ -280,7 +293,7 @@ ots_create_tidy_data <- function(years = NULL,
     } else {
       data %<>%
         dplyr::left_join(dplyr::select(
-          tradestatistics::ots_attributes_countries,
+          tradestatistics::ots_countries,
           !!!rlang::syms(
             c("country_iso", "country_fullname_english")
           )
@@ -306,7 +319,7 @@ ots_create_tidy_data <- function(years = NULL,
   if (table %in% tables_with_partner) {
     data %<>%
       dplyr::left_join(dplyr::select(
-        tradestatistics::ots_attributes_countries,
+        tradestatistics::ots_countries,
         !!!rlang::syms(
           c("country_iso", "country_fullname_english")
         )
@@ -333,7 +346,7 @@ ots_create_tidy_data <- function(years = NULL,
 
   if (table %in% tables_with_product_code) {
     data %<>%
-      dplyr::left_join(tradestatistics::ots_attributes_products, by = "product_code")
+      dplyr::left_join(tradestatistics::ots_products, by = "product_code")
 
     if (table == "yrpc") {
       data %<>%
@@ -386,10 +399,10 @@ ots_create_tidy_data <- function(years = NULL,
         )
     }
   }
-  
+
   if (table %in% product_depending_queries & include_shortnames == TRUE) {
-    data %<>% 
-      dplyr::left_join(tradestatistics::ots_attributes_product_shortnames) %>%
+    data %<>%
+      dplyr::left_join(tradestatistics::ots_product_shortnames) %>%
       dplyr::select(
         !!!rlang::sym(("year")),
         dplyr::starts_with("product_"),
@@ -397,10 +410,10 @@ ots_create_tidy_data <- function(years = NULL,
         dplyr::everything()
       )
   }
-  
+
   if (table %in% product_depending_queries & include_communities == TRUE) {
-    data %<>% 
-      dplyr::left_join(tradestatistics::ots_attributes_communities) %>%
+    data %<>%
+      dplyr::left_join(tradestatistics::ots_communities) %>%
       dplyr::select(
         !!!rlang::sym(("year")),
         dplyr::starts_with("product_"),
